==> django_cfg-1.4.10.tar.gz: django_cfg-1.4.10/src/django_cfg/apps/agents/patterns/content_agents.py <==
"""
Pre-built content processing agents.
"""

from pydantic import BaseModel, Field
from typing import List, Dict, Any

from ..core.agent import DjangoAgent
from ..core.dependencies import ContentDeps, RunContext
from ..core.models import AnalysisResult, ProcessResult, ValidationResult


class ContentAnalysisResult(BaseModel):
    """Result from content analysis."""
    sentiment: str = Field(..., description="Sentiment: positive, negative, neutral")
    confidence: float = Field(..., ge=0.0, le=1.0, description="Confidence score")
    topics: List[str] = Field(default_factory=list, description="Extracted topics")
    keywords: List[str] = Field(default_factory=list, description="Key terms")
    summary: str = Field(default="", description="Content summary")
    readability_score: float = Field(default=0.0, ge=0.0, le=100.0)
    word_count: int = Field(default=0, ge=0)
    language: str = Field(default="unknown", description="Detected language")


class ContentGenerationResult(BaseModel):
    """Result from content generation."""
    generated_content: str = Field(..., description="Generated content")
    content_type: str = Field(..., description="Type of generated content")
    word_count: int = Field(..., ge=0, description="Word count")
    quality_score: float = Field(default=0.0, ge=0.0, le=1.0, description="Quality assessment")
    metadata: Dict[str, Any] = Field(default_factory=dict, description="Additional metadata")


def ContentAnalyzerAgent() -> DjangoAgent[ContentDeps, ContentAnalysisResult]:
    """
    Create content analyzer agent.
    
    Analyzes content for:
    - Sentiment analysis
    - Topic extraction
    - Keyword identification
    - Readability assessment
    - Language detection
    """
    agent = DjangoAgent[ContentDeps, ContentAnalysisResult](
        name="content_analyzer",
        deps_type=ContentDeps,
        output_type=ContentAnalysisResult,
        instructions="""
        You are a content analysis expert. Analyze the provided content and extract:
        
        1. Sentiment (positive, negative, neutral) with confidence score
        2. Main topics and themes
        3. Important keywords and phrases
        4. Content summary (2-3 sentences)
        5. Readability assessment (0-100 scale)
        6. Language detection
        
        Be thorough but concise in your analysis.
        """
    )
    
    @agent.tool
    async def analyze_text_structure(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Analyze text structure and formatting."""
        # This would integrate with actual text analysis libraries
        return {
            "paragraphs": 0,
            "sentences": 0,
            "avg_sentence_length": 0.0,
            "complexity_score": 0.0
        }
    
    @agent.tool
    async def extract_entities(ctx: RunContext[ContentDeps]) -> List[Dict[str, str]]:
        """Extract named entities from content."""
        # This would integrate with NER libraries
        return [
            {"text": "example", "label": "PERSON", "confidence": 0.95}
        ]
    
    @agent.tool
    async def get_content_metadata(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Get content metadata from dependencies."""
        return {
            "content_id": ctx.deps.content_id,
            "content_type": ctx.deps.content_type,
            "target_audience": ctx.deps.target_audience,
            "user_id": ctx.deps.user.id
        }
    
    return agent


def ContentGeneratorAgent() -> DjangoAgent[ContentDeps, ContentGenerationResult]:
    """
    Create content generator agent.
    
    Generates content based on:
    - Content type requirements
    - Target audience
    - Style guidelines
    - Length specifications
    """
    agent = DjangoAgent[ContentDeps, ContentGenerationResult](
        name="content_generator",
        deps_type=ContentDeps,
        output_type=ContentGenerationResult,
        instructions="""
        You are a professional content writer. Generate high-quality content based on:
        
        1. Content type (article, blog post, social media, etc.)
        2. Target audience preferences
        3. Specified tone and style
        4. Length requirements
        5. SEO considerations if applicable
        
        Ensure the content is:
        - Engaging and well-structured
        - Appropriate for the target audience
        - Original and creative
        - Grammatically correct
        - Optimized for readability
        """
    )
    
    @agent.tool
    async def get_style_guidelines(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Get style guidelines for content generation."""
        return {
            "tone": "professional",
            "style": "informative",
            "max_words": 1000,
            "include_headers": True,
            "target_audience": ctx.deps.target_audience
        }
    
    @agent.tool
    async def check_content_requirements(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Check content requirements and constraints."""
        return {
            "content_type": ctx.deps.content_type,
            "min_length": 300,
            "max_length": 2000,
            "required_keywords": [],
            "forbidden_topics": []
        }
    
    @agent.tool
    async def validate_generated_content(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Validate generated content quality."""
        word_count = len(content.split())
        
        return {
            "word_count": word_count,
            "quality_score": 0.85,  # This would be calculated by quality metrics
            "passes_validation": word_count >= 100,
            "suggestions": []
        }
    
    return agent


def ContentValidatorAgent() -> DjangoAgent[ContentDeps, ValidationResult]:
    """
    Create content validator agent.
    
    Validates content for:
    - Grammar and spelling
    - Style consistency
    - Factual accuracy
    - Compliance with guidelines
    - Plagiarism detection
    """
    agent = DjangoAgent[ContentDeps, ValidationResult](
        name="content_validator",
        deps_type=ContentDeps,
        output_type=ValidationResult,
        instructions="""
        You are a content quality assurance expert. Validate content for:
        
        1. Grammar, spelling, and punctuation errors
        2. Style consistency and readability
        3. Factual accuracy and logical flow
        4. Compliance with content guidelines
        5. Potential plagiarism or copyright issues
        
        Provide specific feedback and suggestions for improvement.
        Mark content as valid only if it meets all quality standards.
        """
    )
    
    @agent.tool
    async def check_grammar_spelling(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check grammar and spelling."""
        # This would integrate with grammar checking libraries
        return {
            "grammar_errors": [],
            "spelling_errors": [],
            "grammar_score": 0.95,
            "suggestions": []
        }
    
    @agent.tool
    async def check_style_consistency(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check style consistency."""
        return {
            "style_score": 0.90,
            "inconsistencies": [],
            "tone_analysis": "consistent",
            "readability_grade": 8.5
        }
    
    @agent.tool
    async def check_content_guidelines(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check compliance with content guidelines."""
        return {
            "guideline_compliance": True,
            "violations": [],
            "compliance_score": 0.98,
            "recommendations": []
        }
    
    @agent.tool
    async def check_factual_accuracy(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check factual accuracy of content."""
        return {
            "accuracy_score": 0.92,
            "questionable_claims": [],
            "fact_check_results": [],
            "verification_needed": []
        }
    
    return agent

==> django_cfg-1.4.72.tar.gz: django_cfg-1.4.72/src/django_cfg/apps/agents/patterns/content_agents.py <==
"""
Pre-built content processing agents.
"""

from typing import Any, Dict, List

from pydantic import BaseModel, Field

from ..core.agent import DjangoAgent
from ..core.dependencies import ContentDeps, RunContext
from ..core.models import ValidationResult


class ContentAnalysisResult(BaseModel):
    """Result from content analysis."""
    sentiment: str = Field(..., description="Sentiment: positive, negative, neutral")
    confidence: float = Field(..., ge=0.0, le=1.0, description="Confidence score")
    topics: List[str] = Field(default_factory=list, description="Extracted topics")
    keywords: List[str] = Field(default_factory=list, description="Key terms")
    summary: str = Field(default="", description="Content summary")
    readability_score: float = Field(default=0.0, ge=0.0, le=100.0)
    word_count: int = Field(default=0, ge=0)
    language: str = Field(default="unknown", description="Detected language")


class ContentGenerationResult(BaseModel):
    """Result from content generation."""
    generated_content: str = Field(..., description="Generated content")
    content_type: str = Field(..., description="Type of generated content")
    word_count: int = Field(..., ge=0, description="Word count")
    quality_score: float = Field(default=0.0, ge=0.0, le=1.0, description="Quality assessment")
    metadata: Dict[str, Any] = Field(default_factory=dict, description="Additional metadata")


def ContentAnalyzerAgent() -> DjangoAgent[ContentDeps, ContentAnalysisResult]:
    """
    Create content analyzer agent.
    
    Analyzes content for:
    - Sentiment analysis
    - Topic extraction
    - Keyword identification
    - Readability assessment
    - Language detection
    """
    agent = DjangoAgent[ContentDeps, ContentAnalysisResult](
        name="content_analyzer",
        deps_type=ContentDeps,
        output_type=ContentAnalysisResult,
        instructions="""
        You are a content analysis expert. Analyze the provided content and extract:
        
        1. Sentiment (positive, negative, neutral) with confidence score
        2. Main topics and themes
        3. Important keywords and phrases
        4. Content summary (2-3 sentences)
        5. Readability assessment (0-100 scale)
        6. Language detection
        
        Be thorough but concise in your analysis.
        """
    )

    @agent.tool
    async def analyze_text_structure(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Analyze text structure and formatting."""
        # This would integrate with actual text analysis libraries
        return {
            "paragraphs": 0,
            "sentences": 0,
            "avg_sentence_length": 0.0,
            "complexity_score": 0.0
        }

    @agent.tool
    async def extract_entities(ctx: RunContext[ContentDeps]) -> List[Dict[str, str]]:
        """Extract named entities from content."""
        # This would integrate with NER libraries
        return [
            {"text": "example", "label": "PERSON", "confidence": 0.95}
        ]

    @agent.tool
    async def get_content_metadata(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Get content metadata from dependencies."""
        return {
            "content_id": ctx.deps.content_id,
            "content_type": ctx.deps.content_type,
            "target_audience": ctx.deps.target_audience,
            "user_id": ctx.deps.user.id
        }

    return agent


def ContentGeneratorAgent() -> DjangoAgent[ContentDeps, ContentGenerationResult]:
    """
    Create content generator agent.
    
    Generates content based on:
    - Content type requirements
    - Target audience
    - Style guidelines
    - Length specifications
    """
    agent = DjangoAgent[ContentDeps, ContentGenerationResult](
        name="content_generator",
        deps_type=ContentDeps,
        output_type=ContentGenerationResult,
        instructions="""
        You are a professional content writer. Generate high-quality content based on:
        
        1. Content type (article, blog post, social media, etc.)
        2. Target audience preferences
        3. Specified tone and style
        4. Length requirements
        5. SEO considerations if applicable
        
        Ensure the content is:
        - Engaging and well-structured
        - Appropriate for the target audience
        - Original and creative
        - Grammatically correct
        - Optimized for readability
        """
    )

    @agent.tool
    async def get_style_guidelines(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Get style guidelines for content generation."""
        return {
            "tone": "professional",
            "style": "informative",
            "max_words": 1000,
            "include_headers": True,
            "target_audience": ctx.deps.target_audience
        }

    @agent.tool
    async def check_content_requirements(ctx: RunContext[ContentDeps]) -> Dict[str, Any]:
        """Check content requirements and constraints."""
        return {
            "content_type": ctx.deps.content_type,
            "min_length": 300,
            "max_length": 2000,
            "required_keywords": [],
            "forbidden_topics": []
        }

    @agent.tool
    async def validate_generated_content(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Validate generated content quality."""
        word_count = len(content.split())

        return {
            "word_count": word_count,
            "quality_score": 0.85,  # This would be calculated by quality metrics
            "passes_validation": word_count >= 100,
            "suggestions": []
        }

    return agent


def ContentValidatorAgent() -> DjangoAgent[ContentDeps, ValidationResult]:
    """
    Create content validator agent.
    
    Validates content for:
    - Grammar and spelling
    - Style consistency
    - Factual accuracy
    - Compliance with guidelines
    - Plagiarism detection
    """
    agent = DjangoAgent[ContentDeps, ValidationResult](
        name="content_validator",
        deps_type=ContentDeps,
        output_type=ValidationResult,
        instructions="""
        You are a content quality assurance expert. Validate content for:
        
        1. Grammar, spelling, and punctuation errors
        2. Style consistency and readability
        3. Factual accuracy and logical flow
        4. Compliance with content guidelines
        5. Potential plagiarism or copyright issues
        
        Provide specific feedback and suggestions for improvement.
        Mark content as valid only if it meets all quality standards.
        """
    )

    @agent.tool
    async def check_grammar_spelling(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check grammar and spelling."""
        # This would integrate with grammar checking libraries
        return {
            "grammar_errors": [],
            "spelling_errors": [],
            "grammar_score": 0.95,
            "suggestions": []
        }

    @agent.tool
    async def check_style_consistency(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check style consistency."""
        return {
            "style_score": 0.90,
            "inconsistencies": [],
            "tone_analysis": "consistent",
            "readability_grade": 8.5
        }

    @agent.tool
    async def check_content_guidelines(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check compliance with content guidelines."""
        return {
            "guideline_compliance": True,
            "violations": [],
            "compliance_score": 0.98,
            "recommendations": []
        }

    @agent.tool
    async def check_factual_accuracy(ctx: RunContext[ContentDeps], content: str) -> Dict[str, Any]:
        """Check factual accuracy of content."""
        return {
            "accuracy_score": 0.92,
            "questionable_claims": [],
            "fact_check_results": [],
            "verification_needed": []
        }

    return agent
